

---
# Current click

Current click is an add-on board used for measurement of electric current. It features INA196 current shunt monitor, MCP3201 12-bit ADC, MAX6106 voltage reference as well as two screw terminals. 

<p align="center">
  <img src="http://download.mikroe.com/images/click_for_ide/current_click.png" height=300px>
</p>

[click Product page](<https://www.mikroe.com/current-click>)

---


#### Click library 

- **Author**        : Jovan Stajkovic
- **Date**          : Dec 2019.
- **Type**          : SPI type


# Software Support

We provide a library for the Current Click 
as well as a demo application (example), developed using MikroElektronika 
[compilers](http://shop.mikroe.com/compilers). 
The demo can run on all the main MikroElektronika [development boards](http://shop.mikroe.com/development-boards).

Package can be downloaded/installed directly form compilers IDE(recommended way), or downloaded from our LibStock, or found on mikroE github account. 

## Library Description

> This library contains API for Current Click driver.

#### Standard key functions :

- Config Object Initialization function.
> void current_cfg_setup ( current_cfg_t *cfg ); 
 
- Initialization function.
> CURRENT_RETVAL current_init ( current_t *ctx, current_cfg_t *cfg );


#### Example key functions :

- Function is used to calculate current in mA.
> float current_get_current_data ( current_t *ctx, float r_hunt );

## Examples Description

> 
> Demo app measures and displays current by using Current click board.
> 

**The demo application is composed of two sections :**

### Application Init 

>
> Initalizes SPI, LOG and click drivers.
> 

```c

void application_init ( void )
{
    log_cfg_t log_cfg;
    current_cfg_t cfg;

    //  Logger initialization.

    log_cfg.level = LOG_LEVEL_DEBUG;
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_printf( &logger, "---- Application Init ----\r\n" );

    //  Click initialization.

    current_cfg_setup( &cfg );
    CURRENT_MAP_MIKROBUS( cfg, MIKROBUS_1 );
    current_init( &current, &cfg );
    log_printf( &logger, "-----------------------\r\n" );
    log_printf( &logger, "    Current  Click     \r\n" );
    log_printf( &logger, "-----------------------\r\n" );
}
  
```

### Application Task

>
> This is an example that shows the capabilities of the Current click board 
  by measuring current in miliampers. Current click board can be used to safely
  measure current ranging from 2mA to 2048mA.
> 

```c

void application_task ( void )
{
    //  Task implementation.
    curr = current_get_current_data( &current, CURRENT_RSHUNT_10 );
    
    if( curr == CURRENT_OUT_OF_RANGE )
    {
        log_printf( &logger, "Out of range!  \r\n" );
    }
    else
    {
       log_printf( &logger, " Current: %.2f mA \r\n", curr );
    }
	
    log_printf( &logger, "-----------------------\r\n" );
    Delay_ms( 1000 );
}  

```

## Note

> 
> It is important to provide the shunt of the appropriate value.
> 

The full application code, and ready to use projects can be  installed directly form compilers IDE(recommneded) or found on LibStock page or mikroE GitHub accaunt.

**Other mikroE Libraries used in the example:** 

- MikroSDK.Board
- MikroSDK.Log
- Click.Current

**Additional notes and informations**

Depending on the development board you are using, you may need 
[USB UART click](http://shop.mikroe.com/usb-uart-click), 
[USB UART 2 Click](http://shop.mikroe.com/usb-uart-2-click) or 
[RS232 Click](http://shop.mikroe.com/rs232-click) to connect to your PC, for 
development systems with no UART to USB interface available on the board. The 
terminal available in all Mikroelektronika 
[compilers](http://shop.mikroe.com/compilers), or any other terminal application 
of your choice, can be used to read the message.



---
